@@ -4,7 +4,7 @@ test_that("DynatraceLayout.format_event() - with default settings - format event
   event <- LogEvent$new(
     logger = Logger$new("dum/my"),
     level = 200L,
-    timestamp = structure(1541175573.9308, class = c("POSIXct", "POSIXt")),
+    timestamp = structure(1541175573.9308, class = c("POSIXct", "POSIXt"), tzone = "UTC"),
     caller = "foonction",
     msg = "foo bar",
     rawMsg = "foobar-raw"
@@ -20,7 +20,7 @@ test_that("DynatraceLayout.format_event() - with default settings - format event
 
   expect_identical(res$loglevel, "error")
   expect_identical(res$log.raw_level, "error")
-  expect_identical(res$timestamp, "2018-11-02 17:19:33")
+  expect_identical(res$timestamp, "2018-11-02 16:19:33")
   expect_identical(res$log.logger, "dum.my")
   expect_identical(res$code.function, "foonction")
   expect_identical(res$content, "foo bar")
